#!/bin/bash
################################################################################
# Copyright (C) 2022 NEC Corporation.
#
# This script releases the shared memory allocated by NEC MPI at the end of job.
#
# To use this script, set Epilog parameter in slurm.conf as follows.
# Epilog=/etc/slurm/relmpimem.sh
#
# INPUT: Among the environment variables that epilog program can refer to,
#	 this script refers to the following environment variables.
#
#        SLURM_SCRIPT_CONTEXT: Identifies which epilog or prolog program is
#			       currently running. 
#        SLURM_JOB_USER:       User name of the job's owner.
#	 SLURM_JOB_ID:	       Job ID
#
# OUTPUT: This script always returns exit code 0.
#
# NOTE: If this script and the health check script for VE job are used at the
#       same time, set Epilog parameter so that this script is started first.
#
################################################################################

# Check if epilog program is currently running.
# If not, the process is terminated.
[[ $SLURM_SCRIPT_CONTEXT =~ ^epilog_slurmd$ ]] || exit 0

# Script file for shared memory cleanup provided by NEC MPI.
MEMRELEASE="/opt/nec/ve/mpi/libexec/memrelease.sh"

# Check if the script file exists and has execute permission.
# If not, the process is terminated.
[[ -x $MEMRELEASE ]] || exit 0

# Switches the user to the job's owner.
# Set Job ID to the environment variable PBS_JOBID,
# then start the script for shared memory cleanup.
su "$SLURM_JOB_USER" << EOF
bash -c "export PBS_JOBID=$SLURM_JOB_ID;$MEMRELEASE"
EOF

exit 0
